User Guide
==========

This guide covers all features of Pavise in detail.

.. toctree::
   :maxdepth: 2

   basic-usage
   pandas-backend
   polars-backend
   validators
   strict-mode
   error-messages
